<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:cif="cif">
    <xsl:param name="xslShowHelp" select="cif:xslShowHelp"/>
    <xsl:param name="xslRootDirectory" select="cif:xslRootDirectory"/>

    <!-- Turnout Branch Report -->
    <xsl:template match="/">
        <xsl:variable name="gridOut" select="cif:SetGridOut(number(InRoads/@outputGridScaleFactor))"/>
        <html>
            <head>
                <link rel="stylesheet" type="text/css" href="{$xslRootDirectory}/_Themes/engineer/theme.css"/>
                <!--Title displayed in browser Title Bar-->
                <title lang="en">Výpis větve výhybky</title>
            </head>
            <body>
                <xsl:choose>
                    <xsl:when test="$xslShowHelp = 'true'">
                        <xsl:call-template name="StyleSheetHelp"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:for-each select="InRoads">
                            <center>
                                <!--Report Title-->
                                <h2 lang="en">Výpis větve výhybky</h2>
                                <p lang="en">
                                    Datum výpisu:&#xa0; <xsl:value-of select="cif:date()"/><br />
                                    Čas:&#xa0; <xsl:value-of select="cif:time()"/>
                                </p>
                            </center>
                            
                            <!--Project Data-->
                            <xsl:for-each select="GeometryProject">
                                <table class="margin" cellpadding="2" width="90%">
                                    <tbody>
                                        <tr>
                                            <th align="right" lang="en">Projekt:&#xa0; </th>
                                            <td align="left" colspan="2"><xsl:value-of select="@name"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en">Popis:&#xa0; </th>
                                            <td align="left" colspan="2"><xsl:value-of select="@description"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en" style="font-size: 80%">Koeficient vstupního rastru:&#xa0; </th>
                                            <td align="left" style="font-size: 80%"><xsl:value-of select="../@inputGridScaleFactor" /></td>
                                            <td align="right" lang="en" style="font-size: 80%">
                                                <strong>Poznámka:&#xa0; </strong>Všechny jednotky tohoto výpisu jsou
                                                <xsl:if test="//@linearUnits = 'Imperial'">ve stopách, </xsl:if>
                                                <xsl:if test="//@linearUnits = 'Metric'">v metrech, </xsl:if>
                                                pokud není specifikováno jinak.
                                            </td>
                                        </tr>
                                    </tbody>
                                </table>
                                <hr/>
                                <table class="margin" cellpadding="2" cellspacing="2" width="90%">
                                    <thead>
                                        <tr>
                                            <th class="underline" align="left" lang="en">Výhybka</th>
                                            <th class="underline" align="left" lang="en">Popis</th>
                                            <th class="underline" align="left" lang="en">Styl</th>
                                            <th class="underline" align="left" lang="en">Rodič</th>
                                            <th class="underline" align="left" lang="en">Větev</th>
                                            <th class="underline" align="left" lang="en">Rychlost</th>
                                        </tr>
                                    </thead>
                                    <tbody>
                                        <xsl:for-each select="Turnout">
                                            <tr>
                                                <td class="sidepad" align="left"><xsl:value-of select="@name"/></td>
                                                <td align="left"><xsl:value-of select="@description"/></td>
                                                <td align="left"><xsl:value-of select="@style"/></td>
                                                <td align="left" lang="en">
                                                    <xsl:choose>
                                                        <xsl:when test="*/@mainlineAlignment">
                                                            <xsl:value-of select="*/@mainlineAlignment"/>
                                                        </xsl:when>
                                                        <xsl:otherwise>
                                                            <span style="color:red"><xsl:text>** osiřelá **</xsl:text></span>
                                                        </xsl:otherwise>
                                                    </xsl:choose>
                                                </td>
                                                <td align="left">
                                                    <xsl:choose>
                                                        <xsl:when test="*/@branchAlignment">
                                                            <xsl:value-of select="*/@branchAlignment"/>
                                                        </xsl:when>
                                                        <xsl:otherwise>&#xa0;</xsl:otherwise>
                                                    </xsl:choose>
                                                </td>
                                                <td align="left">
                                                    <xsl:value-of select="format-number(number(*/@mlSpeed), 0)"/>
                                                </td>
                                            </tr>
                                        </xsl:for-each>
                                    </tbody>
                                </table>
                            </xsl:for-each>
                        </xsl:for-each>
                    </xsl:otherwise>
                </xsl:choose>
            </body>
        </html>
    </xsl:template>

    <xsl:template name="StyleSheetHelp">
        <xsl:text>Copyright 2018 Bentley Systems, Inc&#xd;</xsl:text>
    </xsl:template>
</xsl:stylesheet>
